@@ -70,6 +70,7 @@ inline void checkForceFclose(FILE* &fh)
 	}
 }
 
+// more efficient than tDtorEx with lambda
 struct FILE_RAII
 {
 	FILE *p = nullptr;
@@ -82,7 +83,8 @@ private:
 	FILE_RAII operator=(const FILE_RAII&);
 };
 
-
+void mkdirhier(cmstring& path);
+bool xtouch(cmstring &wanted);
 void mkbasedir(const mstring & path);
 
 /*
