@@ -8,13 +8,13 @@
 #include <cstring>
 #include "csmapping.h"
 
-class pkgimport : public tCacheOperation, ifileprocessor
+class pkgimport : public cacheman
 {
 
 public:
 	// XXX: c++11 using tCacheOperation::tCacheOperation;
 	inline pkgimport(const tSpecialRequest::tRunParms& parms)
-	: tCacheOperation(parms) {};
+	: cacheman(parms) {};
 
 	void Action() override;
 	
@@ -22,8 +22,8 @@ protected:
 	// FileHandler
 	bool ProcessRegular(const mstring &sPath, const struct stat &) override;
 	//bool ProcessOthers(const mstring &sPath, const struct stat &);
-	virtual void HandlePkgEntry(const tRemoteFileInfo &entry) override;
 	void _LoadKeyCache();
+	void HandlePkgEntry(const tRemoteFileInfo &entry);
 
 private:
 
