@@ -44,7 +44,7 @@ string tmpDontcache, tmpDontcacheReq, tmpDontcacheTgt, optProxyCheckCmd;
 int optProxyCheckInt = 99;
 
 tStrMap localdirs;
-static class : public lockable, public NoCaseStringMap {} mimemap;
+static class : public base_with_mutex, public NoCaseStringMap {} mimemap;
 
 std::bitset<TCP_PORT_MAX> *pUserPorts = nullptr;
 
@@ -149,7 +149,8 @@ MapNameToInt n2iTbl[] = {
 		,{  "OptProxyTimeout",                   &optproxytimeout,  nullptr,    10}
 		,{  "MaxDlSpeed",                        &maxdlspeed,       nullptr,    10}
 		,{  "MaxInresponsiveDlSize",             &maxredlsize,      nullptr,    10}
-
+		,{  "OptProxyCheckInterval",             &optProxyCheckInt, nullptr,    10}
+		// octal base interpretation of UNIX file permissions
 		,{  "DirPerms",                          &dirperms,         nullptr,    8}
 		,{  "FilePerms",                         &fileperms,        nullptr,    8}
 
@@ -158,7 +159,6 @@ MapNameToInt n2iTbl[] = {
 		,{ "OldIndexUpdater",	&oldupdate, 	"Option is deprecated, ignoring the value." , 10}
 		,{ "Patrace",	&patrace, 				"Don't use in config files!" , 10}
 		,{ "NoSSLchecks",	&nsafriendly, 		"Disable SSL security checks" , 10}
-		,{ "OptProxyCheckInterval", &optProxyCheckInt, nullptr, 10}
 };
 
 
@@ -335,15 +335,16 @@ int * GetIntPtr(LPCSTR key, int &base) {
 	return nullptr;
 }
 
-tProperty* GetPropPtr(LPCSTR key)
+tProperty* GetPropPtr(cmstring& key)
 {
-	auto sep = strrchr(key, '-');
+	auto sep = key.find('-');
+	auto szkey = key.c_str();
 	for (auto &ent : n2pTbl)
 	{
-		if (0 == strcasecmp(key, ent.name))
+		if (0 == strcasecmp(szkey, ent.name))
 			return &ent;
-		// identified as prefix?
-		if(sep && 0 == ent.name[sep-key+1] && 0==strncasecmp(key, ent.name, sep-key+1))
+		// identified as prefix, with matching length?
+		if(sep != stmiss && 0==strncasecmp(szkey, ent.name, sep) && 0 == ent.name[sep+1])
 			return &ent;
 	}
 	return nullptr;
@@ -457,6 +458,9 @@ inline bool ParseOptionLine(const string &sLine, string &key, string &val)
 	if(key.empty())
 		return false; // weird
 
+	if(endsWithSzAr(val, "\\"))
+		cerr << "Warning: multilines are not supported, consider using \\n." <<endl;
+
 	return true;
 }
 
@@ -572,7 +576,7 @@ inline void AddRemapInfo(bool bAsBackend, const string & token,
 	}
 }
 
-struct tHookHandler: public tRepoData::IHookHandler, public lockable
+struct tHookHandler: public tRepoData::IHookHandler, public base_with_mutex
 {
 	string cmdRel, cmdCon;
 	time_t downDuration, downTimeNext;
@@ -792,7 +796,7 @@ bool SetOption(const string &sLine, NoCaseStringMap *pDupeCheck)
 			return false;
 		}
 	}
-	else if ( nullptr != (ppTarget = GetPropPtr(key.c_str())))
+	else if ( nullptr != (ppTarget = GetPropPtr(key)))
 	{
 		return ppTarget->set(key, value);
 	}
@@ -1034,7 +1038,8 @@ void ReadConfigDirectory(const char *szPath, bool bReadErrorIsFatal)
 		for(const auto& x: mapUrl2pVname)
 			nUrls+=x.second.size();
 
-		cerr << "Loaded " << repoparms.size() << " backend descriptors\nLoaded mappings for "
+		if(debug&6)
+			cerr << "Loaded " << repoparms.size() << " backend descriptors\nLoaded mappings for "
 				<< mapUrl2pVname.size() << " hosts and " << nUrls<<" paths\n";
 	}
 }
@@ -1079,8 +1084,10 @@ void PostProcConfig()
 #endif
 	
    if(cachedir.empty() || cachedir[0] != CPATHSEP)
-	   BARF("Cache directory unknown or not absolute, terminating...");
-   
+   {
+	   cerr << "Warning: Cache directory unknown or not absolute, running in degraded mode!" << endl;
+	   degraded=true;
+   }
    if(!rechecks::CompileExpressions())
 	   BARF("An error occurred while compiling file type regular expression!");
    
@@ -1114,7 +1121,7 @@ void PostProcConfig()
 	   mkbasedir(acfg::pidfile);
 
    if(nettimeout < 5) {
-	   cerr << "Warning, NetworkTimeout value too small, using: 5." << endl;
+	   cerr << "Warning: NetworkTimeout value too small, using: 5." << endl;
 	   nettimeout = 5;
    }
 
@@ -1279,7 +1286,7 @@ time_t BackgroundCleanup()
 	return ret;
 }
 
-lockable authLock;
+acmutex authLock;
 
 int CheckAdminAuth(LPCSTR auth)
 {
@@ -1338,7 +1345,7 @@ int CheckAdminAuth(LPCSTR auth)
 #endif // MINIBUILD
 
 static bool proxy_failstate = false;
-lockable proxy_fail_lock;
+acmutex proxy_fail_lock;
 const tHttpUrl* GetProxyInfo()
 {
 	if(proxy_info.sHost.empty())
@@ -1355,7 +1362,7 @@ const tHttpUrl* GetProxyInfo()
 		if(optProxyCheckCmd.empty())
 			proxy_failstate = false;
 		else
-			proxy_failstate = system(optProxyCheckCmd.c_str());
+			proxy_failstate = (bool) system(optProxyCheckCmd.c_str());
 	}
 
 	return proxy_failstate ? nullptr : &proxy_info;
@@ -1503,35 +1510,6 @@ bool MatchUncacheable(const string & in, NOCACHE_PATTYPE type)
 
 } // namespace rechecks
 
-mstring GetDirPart(const string &in)
-{
-	if(in.empty())
-		return sEmptyString;
-
-	tStrPos end = in.find_last_of(CPATHSEP);
-	if(end == stmiss) // none? don't care then
-		return sEmptyString;
-
-	return in.substr(0, end+1);
-}
-
-void mkbasedir(const string & path)
-{
-	if(0==mkdir(GetDirPart(path).c_str(), acfg::dirperms) || EEXIST == errno)
-		return; // should succeed in most cases
-
-	unsigned pos=0; // but skip the cache dir components, if possible
-	if(startsWith(path, acfg::cacheDirSlash))
-	{
-		// pos=acfg::cachedir.size();
-		pos=path.find("/", acfg::cachedir.size()+1);
-	}
-    for(; pos<path.size(); pos=path.find(SZPATHSEP, pos+1))
-    {
-        if(pos>0)
-            mkdir(path.substr(0,pos).c_str(), acfg::dirperms);
-    }
-}
 
 #ifndef MINIBUILD
 LPCSTR ReTest(LPCSTR s)
