@@ -352,8 +352,15 @@ inline bool patchChunk(tPatchSequence& idx, LPCSTR pline, size_t len, tPatchSequ
 
 int maint_job()
 {
-   acfg::SetOption("proxy=", nullptr);
+	acfg::SetOption("proxy=", nullptr);
+
 	LPCSTR envh = getenv("HOSTNAME");
+	if(!envh)
+	{
+		static char buf[500];
+		if(0 == gethostname(buf, sizeof(buf)))
+			envh = buf;
+	}
 	if (!envh)
 		envh = "localhost";
 	LPCSTR req = getenv("ACNGREQ");
@@ -372,6 +379,10 @@ int maint_job()
 		urlPath << '/';
 	urlPath << acfg::reportpage << req;
 
+#ifdef DEBUG
+	cerr << "Constructed URL: " << (string) urlPath <<endl;
+#endif
+
 	CReportItemFactory fac;
 
 	int s = -1;
@@ -552,6 +563,7 @@ void parse_options(int argc, const char **argv, function<void (LPCSTR)> f)
 {
 	LPCSTR szCfgDir=CFGDIR;
 	std::vector<LPCSTR> validargs, nonoptions;
+	bool ignoreCfgErrors = false;
 
 	for (auto p=argv; p<argv+argc; p++)
 	{
@@ -567,6 +579,8 @@ void parse_options(int argc, const char **argv, function<void (LPCSTR)> f)
 		}
 		else if(!strcmp(*p, "--verbose"))
 			g_bVerbose=true;
+		else if(!strcmp(*p, "-i"))
+			ignoreCfgErrors = true;
 		else if(**p) // not empty
 			validargs.emplace_back(*p);
 
@@ -583,14 +597,18 @@ void parse_options(int argc, const char **argv, function<void (LPCSTR)> f)
 		if(!info || !S_ISDIR(info.st_mode))
 			g_missingCfgDir = szCfgDir;
 		else
-			acfg::ReadConfigDirectory(szCfgDir, false);
+			acfg::ReadConfigDirectory(szCfgDir, ignoreCfgErrors);
 	}
 
 	tStrVec non_opt_args;
 
 	for(auto& keyval : validargs)
+	{
+		acfg::g_bQuiet = true;
 		if(!acfg::SetOption(keyval, 0))
 			nonoptions.emplace_back(keyval);
+		acfg::g_bQuiet = false;
+	}
 
 	acfg::PostProcConfig();
 
@@ -772,7 +790,7 @@ int main(int argc, const char **argv)
 		aOffset=0;
 		argv[0] = "maint";
 	}
-	acfg::g_bQuiet = true;
+	acfg::g_bQuiet = false;
 	acfg::g_bNoComplex = true; // no DB for just single variables
 
   parm* parm = nullptr;
