@@ -96,12 +96,17 @@ void parse_options(int argc, const char **argv, bool& bStartCleanup)
 	bool bExtraVerb=false;
 	LPCSTR szCfgDir=nullptr;
 	std::vector<LPCSTR> cmdvars;
+	bool ignoreCfgErrors = false;
 
 	for (auto p=argv+1; p<argv+argc; p++)
 	{
+		if (!strncmp(*p, "--", 2))
+			break;
 		if (!strncmp(*p, "-h", 2))
 			usage();
-		if (!strncmp(*p, "-v", 2))
+		if (!strncmp(*p, "-i", 2))
+			ignoreCfgErrors = true;
+		else if (!strncmp(*p, "-v", 2))
 			bExtraVerb = true;
 		else if (!strncmp(*p, "-e", 2))
 			bStartCleanup=true;
@@ -118,7 +123,7 @@ void parse_options(int argc, const char **argv, bool& bStartCleanup)
 	}
 
 	if(szCfgDir)
-		acfg::ReadConfigDirectory(szCfgDir);
+		acfg::ReadConfigDirectory(szCfgDir, !ignoreCfgErrors);
 
 	for(auto& keyval : cmdvars)
 		if(!acfg::SetOption(keyval, 0))
@@ -227,6 +232,7 @@ static void usage(int retCode) {
 		"-c: configuration directory\n"
 		"-e: on startup, run expiration once\n"
 		"-p: print configuration and exit\n"
+		"-i: ignore configuration loading errors\n"
 #if SUPPWHASH
 		"-H: read a password from STDIN and print its hash\n"
 #endif
@@ -245,12 +251,16 @@ static void usage(int retCode) {
 static void SetupCacheDir()
 {
 	using namespace acfg;
-	if(!Cstat(cacheDirSlash))
+
+	if(acfg::cachedir.empty())
+		return;	// warning was printed
+
+	auto xstore(cacheDirSlash + "_xstore");
+	mkdirhier(xstore);
+	if(!Cstat(xstore))
 	{
-		// well, attempt to create it then
-		mstring path=cacheDirSlash+'/';
-		for(unsigned pos=0; (pos=path.find(SZPATHSEP, pos)) < path.size(); ++pos)
-			mkdir((const char*) path.substr(0,pos).c_str(), (uint) dirperms);
+		cerr << "Error: Cannot create any directory in " << cacheDirSlash << endl;
+		exit(EXIT_FAILURE);
 	}
 
 	struct timeval tv;
