@@ -21,19 +21,19 @@ using namespace std;
 
 
 con::con(int fdId, const char *c) :
-	m_confd(fdId),
-    m_bStopActivity(false),
-    m_dlerthr(0),
-    m_pDlClient(nullptr),
-    m_pTmpHead(nullptr)
+			m_confd(fdId),
+			m_bStopActivity(false),
+			m_dlerthr(0),
+			m_pDlClient(nullptr),
+			m_pTmpHead(nullptr)
 {
 	if(c) // if nullptr, pick up later when sent by the wrapper
 		m_sClientHost=c;
 
-    LOGSTART2("con::con", "fd: " << fdId << ", clienthost: " << c);
+	LOGSTART2("con::con", "fd: " << fdId << ", clienthost: " << c);
 
 #ifdef DEBUG
-    m_nProcessedJobs=0;
+	m_nProcessedJobs=0;
 #endif
 
 };
@@ -50,21 +50,21 @@ con::~con() {
 		delete *jit;
 
 	logstuff.write();
-	
-    if(m_pDlClient) 
-    {
-    	m_pDlClient->SignalStop();
-    	pthread_join(m_dlerthr, nullptr);
-    	
-    	delete m_pDlClient;
-    	m_pDlClient=nullptr;
-    }
-    if(m_pTmpHead)
-    {
-    	delete m_pTmpHead;
-    	m_pTmpHead=nullptr;
-    }
-    aclog::flush();
+
+	if(m_pDlClient)
+	{
+		m_pDlClient->SignalStop();
+		pthread_join(m_dlerthr, nullptr);
+
+		delete m_pDlClient;
+		m_pDlClient=nullptr;
+	}
+	if(m_pTmpHead)
+	{
+		delete m_pTmpHead;
+		m_pTmpHead=nullptr;
+	}
+	aclog::flush();
 }
 
 namespace RawPassThrough
@@ -106,7 +106,7 @@ void PassThrough(acbuf &clientBufIn, int fdClient, cmstring& uri)
 	{
 		direct_connect:
 		m_spOutCon = g_tcp_con_factory.CreateConnected(url.sHost, url.GetPort(), sErr, 0, 0,
-		false, acfg::nettimeout, true);
+				false, acfg::nettimeout, true);
 	}
 	else
 	{
@@ -119,7 +119,7 @@ void PassThrough(acbuf &clientBufIn, int fdClient, cmstring& uri)
 		if (m_spOutCon)
 		{
 			if (!m_spOutCon->StartTunnel(tHttpUrl(url.sHost, url.GetPort(),
-			true), sErr, & proxy->sUserPass, false))
+					true), sErr, & proxy->sUserPass, false))
 			{
 				m_spOutCon.reset();
 			}
@@ -196,79 +196,80 @@ void PassThrough(acbuf &clientBufIn, int fdClient, cmstring& uri)
 void con::WorkLoop() {
 
 	LOGSTART("con::WorkLoop");
-    
+
 	signal(SIGPIPE, SIG_IGN);
-	
-    acbuf inBuf;
-    inBuf.setsize(32*1024);
-    
-    int maxfd=m_confd;
-    while(!m_bStopActivity) {
-        fd_set rfds, wfds;
-        FD_ZERO(&wfds);
-        FD_ZERO(&rfds);
-        
-        FD_SET(m_confd, &rfds);
-        if(inBuf.freecapa()==0)
-        	return; // shouldn't even get here
-        
-        job *pjSender(nullptr);
-    
-        if ( !m_jobs2send.empty())
+
+	acbuf inBuf;
+	inBuf.setsize(32*1024);
+
+	int maxfd=m_confd;
+	while(!m_bStopActivity) {
+		fd_set rfds, wfds;
+		FD_ZERO(&wfds);
+		FD_ZERO(&rfds);
+
+		FD_SET(m_confd, &rfds);
+		if(inBuf.freecapa()==0)
+			return; // shouldn't even get here
+
+		job *pjSender(nullptr);
+
+		if ( !m_jobs2send.empty())
 		{
 			pjSender=m_jobs2send.front();
 			FD_SET(m_confd, &wfds);
 		}
-		
-        
-        ldbg("select con");
 
-        struct timeval tv;
-        tv.tv_sec = acfg::nettimeout;
-        tv.tv_usec = 23;
-        int ready = select(maxfd+1, &rfds, &wfds, nullptr, &tv);
-        
-        if(ready == 0)
-        {
-        	USRDBG("Timeout occurred, apt client disappeared silently?");
-        	return;
-        }
+
+		ldbg("select con");
+
+		struct timeval tv;
+		tv.tv_sec = acfg::nettimeout;
+		tv.tv_usec = 23;
+		int ready = select(maxfd+1, &rfds, &wfds, nullptr, &tv);
+
+		if(ready == 0)
+		{
+			USRDBG("Timeout occurred, apt client disappeared silently?");
+			return;
+		}
 		else if (ready<0)
 		{
 			if (EINTR == errno)
 				continue;
-			
+
 			ldbg("select error in con, errno: " << errno);
 			return; // FIXME: good error message?
 		}
-        
-        ldbg("select con back");
 
-        if(FD_ISSET(m_confd, &rfds)) {
-            int n=inBuf.sysread(m_confd);
-            ldbg("got data: " << n <<", inbuf size: "<< inBuf.size());
-            if(n<=0) // error, incoming junk overflow or closed connection
-            {
-              if(n==-EAGAIN)
-                continue;
-              else
-              {
-            	  ldbg("client closed connection");
-            	  return;
-              }
-            }
-        }
+		ldbg("select con back");
 
-        // split new data into requests
-        while(inBuf.size()>0) {
-        	MYTRY
-        	{
+		if(FD_ISSET(m_confd, &rfds)) {
+			int n=inBuf.sysread(m_confd);
+			ldbg("got data: " << n <<", inbuf size: "<< inBuf.size());
+			if(n<=0) // error, incoming junk overflow or closed connection
+			{
+				if(n==-EAGAIN)
+					continue;
+				else
+				{
+					ldbg("client closed connection");
+					return;
+				}
+			}
+		}
+
+		// split new data into requests
+		while(inBuf.size()>0) {
+			MYTRY
+			{
 				if(!m_pTmpHead)
 					m_pTmpHead = new header();
 				if(!m_pTmpHead)
 					return; // no resources? whatever
-				
-				int nHeadBytes=m_pTmpHead->LoadFromBuf(inBuf.rptr(), inBuf.size());
+
+				m_pTmpHead->clear();
+				int nHeadBytes=m_pTmpHead->Load(inBuf.rptr(), inBuf.size());
 				ldbg("header parsed how? " << nHeadBytes);
 				if(nHeadBytes == 0)
 				{ // Either not enough data received, or buffer full; make space and retry
@@ -324,7 +325,7 @@ void con::WorkLoop() {
 					}
 					return;
 				}
-				
+
 				if (m_sClientHost.empty()) // may come from wrapper... MUST identify itself
 				{
 
@@ -355,39 +356,39 @@ void con::WorkLoop() {
 
 				m_pTmpHead=nullptr; // owned by job now
 			}
-        	MYCATCH(bad_alloc&)
-        	{
-        		return;
-        	}
-        }
-        
-        if(inBuf.freecapa()==0)
-        	return; // cannot happen unless being attacked
+			MYCATCH(bad_alloc&)
+			{
+				return;
+			}
+		}
+
+		if(inBuf.freecapa()==0)
+			return; // cannot happen unless being attacked
 
 		if(FD_ISSET(m_confd, &wfds) && pjSender)
 		{
 			switch(pjSender->SendData(m_confd))
 			{
-				case(job::R_DISCON):
+			case(job::R_DISCON):
 				{
 					ldbg("Disconnect advise received, stopping connection");
 					return;
 				}
-				case(job::R_DONE):
+			case(job::R_DONE):
 				{
-					m_jobs2send.pop_front(); 						
+					m_jobs2send.pop_front();
 					delete pjSender;
 					pjSender=nullptr;
-		
+
 					ldbg("Remaining jobs to send: " << m_jobs2send.size());
 					break;
 				}
-				case(job::R_AGAIN):
-						break;
-				default:
-					break;
+			case(job::R_AGAIN):
+				break;
+			default:
+				break;
 			}
-        }
+		}
 	}
 }
 
@@ -417,7 +418,7 @@ bool con::SetupDownloader(const char *pszOrigin)
 		}
 		else
 			m_pDlClient=new dlcon(false);
-		
+
 		if(!m_pDlClient)
 			return false;
 	}
@@ -440,7 +441,7 @@ void con::__tlogstuff::write()
 {
 	if (sumIn>0)
 		aclog::transfer('I', sumIn, client.c_str(), file.c_str());
-	
+
 	if(sumOut>0)
 		aclog::transfer(bFileIsError ? 'E' : 'O', sumOut, client.c_str(), file.c_str());
 }
