@@ -17,6 +17,7 @@
 #include <cstdio>
 #include <list>
 #include <map>
+#include <unordered_set>
 #include <iostream>
 #include <algorithm>    // std::min_element, std::max_element
 
@@ -45,7 +46,7 @@ int yes(1);
 int g_sockunix(-1);
 vector<int> g_vecSocks;
 
-condition g_ThreadPoolCondition;
+base_with_condition g_ThreadPoolCondition;
 list<con*> g_freshConQueue;
 int g_nStandbyThreads(0);
 int g_nAllConThreadCount(0);
@@ -57,13 +58,13 @@ bool bTerminationMode(false);
 
 void * ThreadAction(void *)
 {
-	lockguard g(g_ThreadPoolCondition);
+	lockuniq g(g_ThreadPoolCondition);
 	list<con*> & Qu = g_freshConQueue;
 
 	while (true)
 	{
 		while (Qu.empty() && !bTerminationMode)
-			g_ThreadPoolCondition.wait();
+			g_ThreadPoolCondition.wait(g);
 
 		if (bTerminationMode)
 			break;
@@ -257,13 +258,21 @@ void Setup()
 
 		    struct addrinfo *res, *p;
 		    if(0!=getaddrinfo(addi, port.c_str(), &hints, &res))
-			   {
-			    perror("Error resolving address for binding");
-			    return;
-			   }
-		    
+		    {
+		    	perror("Error resolving address for binding");
+		    	return;
+		    }
+
+		    std::unordered_set<std::string> dedup;
 		    for(p=res; p; p=p->ai_next)
 		    {
+		    	if(p->ai_family != AF_INET6 && p->ai_family != AF_INET)
+		    		continue;
+
+		    	// processed before?
+		    	if(!dedup.insert(std::string((LPCSTR)p->ai_addr, p->ai_addrlen)).second)
+		    		continue;
+
 		    	int nSockFd = socket(p->ai_family, p->ai_socktype, p->ai_protocol);
 				if (nSockFd<0)
 					goto error_socket;
@@ -350,6 +359,12 @@ int Run()
 {
 	LOGSTART2s("Run", "GoGoGo");
 
+	if(g_vecSocks.empty())
+	{
+		cerr << "No valid server sockets configured" <<endl;
+		exit(EXIT_FAILURE);
+	}
+
 #ifdef HAVE_SD_NOTIFY
 	sd_notify(0, "READY=1");
 #endif
