@@ -2,6 +2,7 @@
 #include <unistd.h>
 #include <sys/time.h>
 #include <atomic>
+#include <algorithm>
 
 #define LOCAL_DEBUG
 #include "debug.h"
@@ -27,6 +28,14 @@ using namespace std;
 
 static cmstring sGenericError("567 Unknown download error occured");
 
+// those are not allowed to be forwarded
+static const auto taboo =
+{
+	string("Host"), string("Cache-Control"),
+	string("Proxy-Authorization"), string("Accept"),
+	string("User-Agent")
+};
+
 std::atomic_uint g_nDlCons(0);
 
 dlcon::dlcon(bool bManualExecution, string *xff, IDlConFactory *pConFactory) :
@@ -147,24 +156,19 @@ struct tDlJob
 		if(!reqHead)
 			return;
 		header h;
-		tLPS cheaders;
-		h.Load(reqHead, std::numeric_limits<int>::max(), &cheaders);
-		if(cheaders.empty())
-			return;
-		for(const auto& ch: cheaders)
-		{
-			// some headers are reserved (actually all starting with those prefixes
-			if(strncasecmp(ch.first.c_str(), WITHLEN("Host")) &&
-					strncasecmp(ch.first.c_str(), WITHLEN("Proxy-Authorization")) &&
-					strncasecmp(ch.first.c_str(), WITHLEN("Cache-Control")) &&
-					strncasecmp(ch.first.c_str(), WITHLEN("Accept")) &&
-					strncasecmp(ch.first.c_str(), WITHLEN("User-Agent"))
-					)
-			{
-				m_extraHeaders += ch.first;
-				m_extraHeaders += ch.second;
-			}
-		}
+		bool forbidden=false;
+		h.Load(reqHead, std::numeric_limits<int>::max(),
+				[this, &forbidden](cmstring& key, cmstring& rest)
+				{
+			// heh, continuation of ignored stuff or without start?
+			if(key.empty() && (m_extraHeaders.empty() || forbidden))
+				return;
+			forbidden = taboo.end() != std::find_if(taboo.begin(), taboo.end(),
+					[&key](cmstring &x){return scaseequals(x,key);});
+			if(!forbidden)
+				m_extraHeaders += key + rest;
+				}
+		);
 	}
 
 	inline string RemoteUri(bool bUrlEncoded)
@@ -393,7 +397,9 @@ struct tDlJob
 
 		head << acfg::requestapx
 				<< m_extraHeaders
-				<< "Accept: */*\r\nAccept-Encoding: identity\r\nConnection: "
+				<< "Accept: application/octet-stream\r\n"
+				"Accept-Encoding: identity\r\n"
+				"Connection: "
 				<< (acfg::persistoutgoing ? "keep-alive\r\n\r\n" : "close\r\n\r\n");
 
 #ifdef SPAM
@@ -459,7 +465,12 @@ struct tDlJob
 				bool bHotItem = (m_DlState == STATE_REGETHEADER);
 				dbgline;
 
-				auto hDataLen = h.LoadFromBuf(inBuf.rptr(), inBuf.size());
+				auto hDataLen = h.Load(inBuf.rptr(), inBuf.size(),
+						[&h](cmstring& key, cmstring& rest)
+						{ if(scaseequals(key, "Content-Location"))
+							h.frontLine = "HTTP/1.1 500 Apt-Cacher NG does not like that data";
+						});
+
 				if (0 == hDataLen)
 					return HINT_MORE;
 				if (hDataLen<0)
