@@ -1,4 +1,3 @@
-
 //#define LOCAL_DEBUG
 #include "debug.h"
 
@@ -35,8 +34,10 @@ using namespace std;
 
 void expiration::HandlePkgEntry(const tRemoteFileInfo &entry)
 {
-	LOGSTART2("expiration::_HandlePkgEntry:",
+#ifdef DEBUGSPAM
+	LOGSTART2("expiration::HandlePkgEntry:",
 			"\ndir:" << entry.sDirectory << "\nname: " << entry.sFileName << "\nsize: " << entry.fpr.size << "\ncsum: " << entry.fpr.GetCsAsString());
+#endif
 
 #define ECLASS "<span class=\"ERROR\">ERROR: "
 #define WCLASS "<span class=\"WARNING\">WARNING: "
@@ -55,11 +56,11 @@ void expiration::HandlePkgEntry(const tRemoteFileInfo &entry)
 				string sPathAbs(CACHE_BASE+sPathRel);
 
 				// end line ending starting from a class and add checkbox as needed
-				auto finish_bad = [&]()->bool
+				auto finish_bad = [&](cmstring& reason)->bool
 				{
 					if (m_damageList.is_open()) m_damageList << sPathRel << "\n";
 					SendChunk(" (treating as damaged file...) ");
-					AddDelCbox(sPathRel);
+					AddDelCbox(sPathRel, reason);
 					SendChunk(CLASSEND);
 					return true;
 				};
@@ -87,7 +88,7 @@ void expiration::HandlePkgEntry(const tRemoteFileInfo &entry)
 				if(m_bVerbose)
 				{
 					SendFmt << WCLASS << sPathRel << " (invalid but volatile, ignoring...) ";
-					AddDelCbox(sPathRel);
+					AddDelCbox(sPathRel, "Bad file state while containing volatile index data");
 					SendChunk(CLASSEND);
 				}
 				ADDSPACE(size);
@@ -114,15 +115,11 @@ void expiration::HandlePkgEntry(const tRemoteFileInfo &entry)
 			// Basic header checks. Skip if the file was forcibly updated/reconstructed before.
 			if (m_bSkipHeaderChecks || descHave.bNoHeaderCheck)
 			{
-				LOG("Skipped header check for " << sPathRel);
-			}
-			else if(entry.bInflateForCs)
-			{
-				LOG("Skipped header check for " << sPathRel << ", cannot compare sizes");
+//				LOG("Skipped header check for " << sPathRel);
 			}
 			else if(entry.fpr.size>=0)
 			{
-				LOG("Doing basic header checks");
+//				LOG("Doing basic header checks");
 				header h;
 				auto sHeadAbs(sPathAbs+".head");
 				if (0<h.LoadFromFile(sHeadAbs))
@@ -131,9 +128,9 @@ void expiration::HandlePkgEntry(const tRemoteFileInfo &entry)
 					if(lenFromHeader<0)
 					{
 						// better drop it, properly downloaded ones DO have the length
-						SendFmt << WCLASS "header file of "
-						<< sPathRel << " does not contain content length";
-						return finish_bad();
+						SendFmt << WCLASS << sPathRel << ": " <<
+								"header file does not contain content length";
+						return finish_bad("header file does not contain content length");
 					}
 					if (lenFromHeader < lenFromStat)
 					{
@@ -143,7 +140,7 @@ void expiration::HandlePkgEntry(const tRemoteFileInfo &entry)
 						<< " reported too small file size (" << lenFromHeader <<
 						" vs. " << lenFromStat
 						<< "); invalidating file, removing header now";
-						return finish_bad();
+						return finish_bad("metadata reports incorrect file size");
 					}
 				}
 				else
@@ -162,8 +159,7 @@ void expiration::HandlePkgEntry(const tRemoteFileInfo &entry)
 				// can check a bit more against directory info for most cases
 				// also shortcut without scanning
 
-				if( !entry.bInflateForCs &&
-						entry.fpr.size>=0)
+				if(entry.fpr.size>=0)
 				{
 					if(lenFromStat > entry.fpr.size) goto report_oversize;
 					if(lenFromStat < entry.fpr.size) goto handle_incomplete;
@@ -173,8 +169,7 @@ void expiration::HandlePkgEntry(const tRemoteFileInfo &entry)
 			if(!m_bByChecksum) return report_good(lenFromStat);
 
 			//knowing the expected and real size, try a shortcut without scanning
-			if(!entry.bInflateForCs// if we can check quickly with the file size
-					&& entry.fpr.size >= 0)
+			if(entry.fpr.size >= 0)
 			{
 				if(lenFromStat<0) lenFromStat=GetFileSize(sPathAbs, -123);
 				if(lenFromStat >=0 && lenFromStat < entry.fpr.size)
@@ -185,16 +180,13 @@ void expiration::HandlePkgEntry(const tRemoteFileInfo &entry)
 			}
 
 			if(entry.fpr.csType != descHave.fpr.csType &&
-					!descHave.fpr.ScanFile(sPathAbs, entry.fpr.csType, entry.bInflateForCs))
+					!descHave.fpr.ScanFile(sPathAbs, entry.fpr.csType))
 			{
 				// IO error? better keep it for now, not sure how to deal with it
 				SendFmt << ECLASS "An error occurred while checksumming "
 				<< sPathRel << ", leaving as-is for now.";
-				if(entry.bInflateForCs)
-					SendFmt << " NOTE: this can be caused by the incomplete compression"
-							" header if the download was not finished.";
 				aclog::err(tSS() << "Error reading " << sPathAbs );
-				AddDelCbox(sPathRel);
+				AddDelCbox(sPathRel, "IO error");
 				SendFmt<<CLASSEND;
 				return false;
 			}
@@ -204,7 +196,7 @@ void expiration::HandlePkgEntry(const tRemoteFileInfo &entry)
 			if(!descHave.fpr.csEquals(entry.fpr))
 			{
 				SendFmt << ECLASS << "checksum mismatch on " << sPathRel;
-				return finish_bad();
+				return finish_bad("checksum mismatch");
 			}
 
 			// good, or cannot check so must be good
@@ -227,7 +219,7 @@ repro: check by path, after a minor distro upgrade
 					return report_weird_volatile(lenFromStat);
 
 				SendFmt << ECLASS << "size mismatch on " << sPathRel;
-				return finish_bad();
+				return finish_bad("checksum mismatch");
 			}
 
 			// all remaining cases mean an incomplete download
@@ -239,7 +231,7 @@ repro: check by path, after a minor distro upgrade
 				{
 					SendFmt << WCLASS << sPathRel
 							<< " (incomplete download, ignoring...) ";
-					AddDelCbox(sPathRel);
+					AddDelCbox(sPathRel, "Incomplete download");
 					return finish_good(lenFromStat);
 				}
 				// just continue silently
@@ -261,7 +253,7 @@ repro: check by path, after a minor distro upgrade
 			}
 
 			SendFmt << ECLASS << " incomplete download, invalidating (as requested) "<< sPathRel;
-			return finish_bad();
+			return finish_bad("incomplete download");
 		};
 
 	auto rangeIt = m_trashFile2dir2Info.find(entry.sFileName);
@@ -277,10 +269,14 @@ repro: check by path, after a minor distro upgrade
 				rangeIt->second.erase(it++);
 			};
 
-	// needs to match the exact file location.
+	// needs to match the exact file location if requested.
 	// And for "Index" files, they have always to be at a well defined location, this
 	// constraint is also needed to expire deprecated files
-	if(m_bByPath || entry.sFileName == sIndex)
+	// and in general, all kinds of index files shall be checked at the particular location since
+	// there are too many identical names spread between different repositories
+	bool byPath = (m_bByPath || entry.sFileName == sIndex ||
+			rechecks::Match(entry.sDirectory + entry.sFileName, rechecks::FILE_VOLATILE));
+	if(byPath)
 	{
 		// compare full paths (physical vs. remote) with their real paths
 		auto cleanPath(entry.sDirectory);
@@ -416,8 +412,12 @@ inline void expiration::RemoveAndStoreStatus(bool bPurgeNow)
 			}
 			else if (Match(fileGroup.first, FILE_WHITELIST) || Match(sPathRel, FILE_WHITELIST))
 			{
-				LOG("Protected file, not to be removed");
-				continue;
+				// exception is stuff that should have some cover but doesn't
+				if(!ContHas(m_managedDirs, dir_props.first))
+				{
+					LOG("Protected file, not to be removed");
+					continue;
+				}
 			}
 
 			if (dir_props.second.nLostAt<=0) // heh, accidentally added?
@@ -467,82 +467,20 @@ void expiration::Action()
 	}
 	if (m_parms.type==workExList)
 	{
-		LoadPreviousData(true);
-		off_t nSpace(0);
-		unsigned cnt(0);
-		for (auto& i : m_trashFile2dir2Info)
-		{
-			for (auto& j : i.second)
-			{
-				auto rel = (j.first + i.first);
-				auto abspath = SABSPATH(rel);
-				off_t sz = GetFileSize(abspath, -2);
-				if (sz < 0)
-					continue;
-
-				cnt++;
-				SendChunk(rel + "<br>\n");
-				nSpace += sz;
-
-				sz = GetFileSize(abspath + ".head", -2);
-				if (sz >= 0)
-				{
-					nSpace += sz;
-					SendChunk(rel + ".head<br>\n");
-				}
-			}
-		}
-		TellCount(cnt, nSpace);
-
-		mstring delURL(m_parms.cmd);
-		StrSubst(delURL, "justShow", "justRemove");
-		SendFmtRemote << "<a href=\""<<delURL<<"\">Delete all listed files</a> "
-				"(no further confirmation)<br>\n";
+		ListExpiredFiles();
 		return;
 	}
-
 	if(m_parms.type==workExPurgeDamaged || m_parms.type==workExListDamaged || m_parms.type==workExTruncDamaged)
 	{
-		filereader f;
-		if(!f.OpenFile(SABSPATH(FNAME_DAMAGED)))
-		{
-			SendChunk(WITHLEN("List of damaged files not found"));
-			return;
-		}
-		mstring s;
-		while(f.GetOneLine(s))
-		{
-			if(s.empty())
-				continue;
-
-			if(m_parms.type == workExPurgeDamaged)
-			{
-				SendFmt << "Removing " << s << "<br>\n";
-				::unlink(SZABSPATH(s));
-				::unlink(SZABSPATH(s+".head"));
-			}
-			else if(m_parms.type == workExTruncDamaged)
-			{
-				SendFmt << "Truncating " << s << "<br>\n";
-				ignore_value(::truncate(SZABSPATH(s), 0));
-			}
-			else
-				SendFmt << s << "<br>\n";
-		}
+		HandleDamagedFiles();
 		return;
 	}
 
-	SetCommonUserFlags(m_parms.cmd);
-
 	m_bIncompleteIsDamaged=StrHas(m_parms.cmd, "incomAsDamaged");
 	m_bScanVolatileContents=StrHas(m_parms.cmd, "scanVolatile");
 
 	SendChunk("<b>Locating potentially expired files in the cache...</b><br>\n");
-
-	//dump_proc_status();
-	DirectoryWalk(acfg::cachedir, this);
-	//dump_proc_status();
-
+	BuildCacheFileList();
 	if(CheckStopSignal())
 		goto save_fail_count;
 	SendFmt<<"Found "<<m_nProgIdx<<" files.<br />\n";
@@ -572,7 +510,28 @@ void expiration::Action()
 	m_damageList.open(SZABSPATH(FNAME_DAMAGED), ios::out | ios::trunc);
 
 	SendChunk(WITHLEN("<b>Validating cache contents...</b><br>\n"));
-	ProcessSeenMetaFiles(*this);
+
+	// by-hash stuff needs special handling...
+	for(const auto& sPathRel : GetGoodReleaseFiles())
+	{
+		auto func = [this](const tRemoteFileInfo &e) {
+			auto hexname(BytesToHexString(e.fpr.csum, GetCSTypeLen(e.fpr.csType)));
+			auto hit = m_trashFile2dir2Info.find(hexname);
+			if(hit == m_trashFile2dir2Info.end())
+				return; // unknown
+			if(!m_bByPath)
+			{
+				m_trashFile2dir2Info.erase(hit);
+				return;
+			}
+			auto sdir = e.sDirectory + "by-hash/" + GetCsNameReleaseFile(e.fpr.csType) + '/';
+			hit->second.erase(sdir);
+		};
+		ParseAndProcessMetaFile(func, sPathRel, EIDX_RELEASE, true);
+	}
+
+	ProcessSeenIndexFiles([this](const tRemoteFileInfo &e) {
+		HandlePkgEntry(e); });
 
 	if(CheckAndReportError() || CheckStopSignal())
 		goto save_fail_count;
@@ -588,7 +547,7 @@ void expiration::Action()
 
 	PrintStats("Allocated disk space");
 
-	SendChunk("<br>Done.");
+	SendChunk("<br>Done.<br>");
 
 	save_fail_count:
 
@@ -622,6 +581,73 @@ void expiration::Action()
 
 }
 
+void expiration::ListExpiredFiles()
+{
+	LoadPreviousData(true);
+	off_t nSpace(0);
+	unsigned cnt(0);
+	for (auto& i : this->m_trashFile2dir2Info)
+		{
+			for (auto& j : i.second)
+			{
+				auto rel = (j.first + i.first);
+				auto abspath = SABSPATH(rel);
+				off_t sz = GetFileSize(abspath, -2);
+				if (sz < 0)
+					continue;
+
+				cnt++;
+				this->SendChunk(rel + "<br>\n");
+				nSpace += sz;
+
+				sz = GetFileSize(abspath + ".head", -2);
+				if (sz >= 0)
+				{
+					nSpace += sz;
+					this->SendChunk(rel + ".head<br>\n");
+				}
+			}
+		}
+	this->TellCount(cnt, nSpace);
+
+	mstring delURL(this->m_parms.cmd);
+	StrSubst(delURL, "justShow", "justRemove");
+	SendFmtRemote << "<a href=\""<<delURL<<"\">Delete all listed files</a> "
+				"(no further confirmation)<br>\n";
+	return;
+}
+
+void expiration::HandleDamagedFiles()
+{
+	filereader f;
+	if(!f.OpenFile(SABSPATH(FNAME_DAMAGED)))
+		{
+			this->SendChunk(WITHLEN("List of damaged files not found"));
+			return;
+		}
+	mstring s;
+	while(f.GetOneLine(s))
+		{
+			if(s.empty())
+				continue;
+
+			if(this->m_parms.type == workExPurgeDamaged)
+			{
+				SendFmt << "Removing " << s << "<br>\n";
+				unlink(SZABSPATH(s));
+				unlink(SZABSPATH(s+".head"));
+			}
+			else if(this->m_parms.type == workExTruncDamaged)
+			{
+				SendFmt << "Truncating " << s << "<br>\n";
+				ignore_value(truncate(SZABSPATH(s), 0));
+			}
+			else
+				SendFmt << s << "<br>\n";
+		}
+	return;
+}
+
 void expiration::PurgeMaintLogs()
 {
 	tStrDeq logs = ExpandFilePattern(acfg::logdir + SZPATHSEP MAINT_PFX "*.log*");
@@ -821,3 +847,21 @@ void expiration::MarkObsolete(cmstring& sPathRel)
 {
 	m_killBill.emplace_back(sPathRel);
 }
+
+bool expiration::_checkSolidHashOnDisk(cmstring& hexname, const tRemoteFileInfo& entry,
+		cmstring& srcPrefix)
+{
+	if(m_trashFile2dir2Info.find(hexname) == m_trashFile2dir2Info.end())
+		return false;
+	return cacheman::_checkSolidHashOnDisk(hexname, entry, srcPrefix);
+}
+
+bool expiration::_QuickCheckSolidFileOnDisk(cmstring& sPathRel)
+{
+	auto dir=GetDirPart(sPathRel);
+	auto nam=sPathRel.substr(dir.size());
+	auto it = m_trashFile2dir2Info.find(nam);
+	if(it == m_trashFile2dir2Info.end())
+		return false;
+	return it->second.find(dir) != it->second.end();
+}
