@@ -14,13 +14,16 @@
 #include <errno.h>
 #include <algorithm>
 
+#include <sys/stat.h>
+#include <sys/types.h>
+
 using namespace std;
 
 #define MAXTEMPDELAY acfg::maxtempdelay // 27
 mstring sReplDir("_altStore" SZPATHSEP);
 
 static tFiGlobMap mapItems;
-static lockable mapItemsMx;
+static acmutex mapItemsMx;
 
 header const & fileitem::GetHeaderUnlocked()
 {
@@ -36,7 +39,6 @@ string fileitem::GetHttpMsg()
 }
 
 fileitem::fileitem() :
-	condition(),
 	m_nIncommingCount(0),
 	m_nSizeSeen(0),
 	m_nRangeLimit(-1),
@@ -286,9 +288,9 @@ void fileitem::SetupComplete()
 
 fileitem::FiStatus fileitem::WaitForFinish(int *httpCode)
 {
-	setLockGuard;
+	lockuniq g(this);
 	while(m_status<FIST_COMPLETE)
-		wait();
+		wait(g);
 	if(httpCode)
 		*httpCode=m_head.getStatus();
 	return m_status;
@@ -308,7 +310,6 @@ bool fileitem_with_storage::DownloadStartedStoreHeader(const header & h, size_t
 		bool bForcedRestart, bool &bDoCleanRetry)
 {
 	LOGSTART("fileitem::DownloadStartedStoreHeader");
-
 	auto SETERROR = [&](LPCSTR x) {
 		m_bAllowStoreData=false;
 		m_head.frontLine=mstring("HTTP/1.1 ")+x;
@@ -530,8 +531,10 @@ bool fileitem_with_storage::DownloadStartedStoreHeader(const header & h, size_t
 	if(m_bAllowStoreData)
 	{
 		// using adaptive Delete-Or-Replace-Or-CopyOnWrite strategy
-		
-		// First opening the file first to be sure that it can be written. Header storage is the critical point,
+
+		MoveRelease2Sidestore();
+
+		// First opening the file to be sure that it can be written. Header storage is the critical point,
 		// every error after that leads to full cleanup to not risk inconsistent file contents 
 		
 		int flags = O_WRONLY | O_CREAT | O_BINARY;
@@ -759,7 +762,7 @@ inline void fileItemMgmt::Unreg()
 }
 
 
-bool fileItemMgmt::PrepageRegisteredFileItemWithStorage(cmstring &sPathUnescaped, bool bConsiderAltStore)
+bool fileItemMgmt::PrepareRegisteredFileItemWithStorage(cmstring &sPathUnescaped, bool bConsiderAltStore)
 {
 	LOGSTART2("fileitem::GetFileItem", sPathUnescaped);
 
@@ -948,4 +951,20 @@ fileitem_with_storage::~fileitem_with_storage()
 	}
 }
 
+// special file? When it's rewritten from start, save the old version instead
+int fileitem_with_storage::MoveRelease2Sidestore()
+{
+	if(m_nSizeChecked)
+		return 0;
+	if(!endsWithSzAr(m_sPathRel, "/InRelease") && !endsWithSzAr(m_sPathRel, "/Release"))
+		return 0;
+	auto tgtDir = CACHE_BASE + acfg::privStoreRelSnapSufix + sPathSep + GetDirPart(m_sPathRel);
+	mkdirhier(tgtDir);
+	auto srcAbs = CACHE_BASE + m_sPathRel;
+	Cstat st(srcAbs);
+	auto sideFileAbs = tgtDir + ltos(st.st_ino) + ltos(st.st_mtim.tv_sec) + ltos(st.st_mtim.tv_nsec);
+	return FileCopy(srcAbs, sideFileAbs);
+	//return rename(srcAbs.c_str(), sideFileAbs.c_str());
+}
+
 #endif // MINIBUILD
