@@ -83,7 +83,7 @@ public:
 	}
 	virtual bool StoreFileData(const char *data, unsigned int size) override
 	{
-		setLockGuard;
+		lockuniq g(this);
 
 		LOGSTART2("tPassThroughFitem::StoreFileData", "status: " << m_status);
 
@@ -107,7 +107,7 @@ public:
 			m_nConsumable=size;
 			m_nConsumed=0;
 			while(0 == m_nConsumed && m_status <= FIST_COMPLETE)
-				wait();
+				wait(g);
 
 			dbgline;
 			// let the downloader abort?
@@ -123,12 +123,12 @@ public:
 	}
 	ssize_t SendData(int out_fd, int, off_t &nSendPos, size_t nMax2SendNow) override
 	{
-		setLockGuard;
+		lockuniq g(this);
 
 		while(0 == m_nConsumable && m_status<=FIST_COMPLETE
 				&& ! (m_nSizeChecked==0 && m_status==FIST_COMPLETE))
 		{
-			wait();
+			wait(g);
 		}
 		if (m_status >= FIST_DLERROR || !m_pData)
 			return -1;
@@ -151,7 +151,7 @@ public:
 			m_nConsumed+=r;
 			nSendPos+=r;
 		}
-		notify();
+		notifyAll();
 		return r;
 	}
 };
@@ -235,7 +235,7 @@ job::~job()
 }
 
 
-inline void job::HandleLocalDownload(const string &visPath,
+inline void job::PrepareLocalDownload(const string &visPath,
 		const string &fsBase, const string &fsSubpath)
 {
 	string absPath = fsBase+SZPATHSEP+fsSubpath;
@@ -396,6 +396,9 @@ inline void job::HandleLocalDownload(const string &visPath,
 			m_head.type=header::ANSWER;
 			m_head.frontLine="HTTP/1.1 200 OK";
 			m_head.set(header::CONTENT_LENGTH, stdata.st_size);
+			m_head.prep(header::LAST_MODIFIED, 26);
+			if(m_head.h[header::LAST_MODIFIED])
+				FormatTime(m_head.h[header::LAST_MODIFIED], 26, stdata.st_mtim.tv_sec);
 			cmstring &sMimeType=acfg::GetMimeType(sLocalPath);
 			if(!sMimeType.empty())
 				m_head.set(header::CONTENT_TYPE, sMimeType);
@@ -549,7 +552,8 @@ void job::PrepareDownload(LPCSTR headBuf) {
 			tStrMap::const_iterator it = acfg::localdirs.find(theUrl.sHost);
 			if (it != acfg::localdirs.end())
 			{
-				HandleLocalDownload(sReqPath, it->second, theUrl.sPath);
+				PrepareLocalDownload(sReqPath, it->second, theUrl.sPath);
+				ParseRange();
 				return;
 			}
 		}
@@ -585,7 +589,8 @@ void job::PrepareDownload(LPCSTR headBuf) {
 			m_sFileLoc=theUrl.sHost+theUrl.sPath;
 
 		bForceFreshnessChecks = ( ! acfg::offlinemode && m_type == FILE_VOLATILE);
-		m_pItem.PrepageRegisteredFileItemWithStorage(m_sFileLoc, bForceFreshnessChecks);
+
+		m_pItem.PrepareRegisteredFileItemWithStorage(m_sFileLoc, bForceFreshnessChecks);
 
 	}
 	MYCATCH(std::out_of_range&) // better safe...
@@ -598,6 +603,9 @@ void job::PrepareDownload(LPCSTR headBuf) {
     	USRDBG("Error creating file item for " << m_sFileLoc);
     	goto report_overload;
     }
+
+    if(acfg::degraded)
+       goto report_degraded;
     
     fistate = m_pItem.get()->Setup(bForceFreshnessChecks);
 	LOG("Got initial file status: " << fistate);
@@ -699,6 +707,10 @@ report_invpath:
 	SetErrorResponse("403 Invalid path specification");
     return ;
 
+report_degraded:
+	SetErrorResponse("403 Cache server in degraded mode");
+	return ;
+
 report_invport:
 	SetErrorResponse("403 Configuration error (confusing proxy mode) or prohibited port (see AllowUserPorts)");
     return ;
@@ -730,7 +742,7 @@ job::eJobResult job::SendData(int confd)
 
 	if (m_pItem)
 	{
-		lockguard g(m_pItem.get().get());
+		lockuniq g(m_pItem.get().get());
 		
 		for(;;)
 		{
@@ -770,7 +782,7 @@ job::eJobResult job::SendData(int confd)
 				break;
 			
 			dbgline;
-			m_pItem.get()->wait();
+			m_pItem.get()->wait(g);
 			
 			dbgline;
 		}
