@@ -70,12 +70,8 @@ void pkgmirror::Action()
 
 	SendChunk("<b>Locating index files, scanning...</b><br>\n");
 
-	SetCommonUserFlags(m_parms.cmd);
-	m_bErrAbort=false; // does not f...ing matter, do what we can
-
 	m_bCalcSize=(m_parms.cmd.find("calcSize=cs")!=stmiss);
 	m_bDoDownload=(m_parms.cmd.find("doDownload=dd")!=stmiss);
-	m_bSkipIxUpdate=(m_parms.cmd.find("skipIxUp=si")!=stmiss);
 	m_bAsNeeded=(m_parms.cmd.find("asNeeded=an")!=stmiss);
 	m_bUseDelta=(m_parms.cmd.find("useDebDelta=ud")!=stmiss);
 
@@ -95,7 +91,7 @@ void pkgmirror::Action()
 	if(m_bUseDelta)
 		StartDlder();
 
-	DirectoryWalk(acfg::cachedir, this);
+	BuildCacheFileList();
 
 	if(CheckStopSignal())
 		return;
@@ -117,29 +113,21 @@ void pkgmirror::Action()
 
 	// prepare wildcard matching and collecting
 	tStrSet srcs;
-	class __srcpicker : public ifileprocessor
-	{
-	public:
-		tStrSet *pSrcs;
-		tStrVec matchList;
-		__srcpicker(tStrSet *x) : pSrcs(x)
-		{
-			Tokenize(acfg::mirrorsrcs, SPACECHARS, matchList);
-		};
-		void TryAdd(cmstring &s)
-		{
-			for(const auto& match : matchList)
-				if(0==fnmatch(match.c_str(), s.c_str(), FNM_PATHNAME))
-				{
-					pSrcs->insert(s);
-					break;
-				}
-		}
-		void HandlePkgEntry(const tRemoteFileInfo &entry)
-		{
-			TryAdd(entry.sDirectory+entry.sFileName);
-		}
-	} picker(&srcs);
+	tStrVec matchList;
+	Tokenize(acfg::mirrorsrcs, SPACECHARS, matchList);
+	auto TryAdd = [&matchList, &srcs](cmstring &s)
+			{
+				for(const auto& match : matchList)
+					if(0==fnmatch(match.c_str(), s.c_str(), FNM_PATHNAME))
+					{
+#ifdef COMPATGCC47
+						srcs.insert(s);
+#else
+						srcs.emplace(s);
+#endif
+						break;
+					}
+			};
 
 	mstring sErr;
 
@@ -151,24 +139,26 @@ void pkgmirror::Action()
 		{
 			if(!m_bSkipIxUpdate && !GetFlags((cmstring)path2x.first).uptodate)
 				Download((cmstring)path2x.first, true, eMsgShow);
-			ParseAndProcessMetaFile(picker, (cmstring) path2x.first, EIDX_RELEASE);
+			ParseAndProcessMetaFile([&TryAdd](const tRemoteFileInfo &entry) {
+				TryAdd(entry.sDirectory+entry.sFileName); },
+				(cmstring) path2x.first, EIDX_RELEASE);
 		}
 		else
-			picker.TryAdd((cmstring)path2x.first);
+			TryAdd((cmstring)path2x.first);
 	}
 
 	SendChunk("<b>Identifying more index files in cache...</b><br>");
 	// unless found in release files, get the from the local system
-	for (const auto& match: picker.matchList)
+	for (const auto& match: matchList)
 		for(const auto& path : ExpandFilePattern(CACHE_BASE+match, false))
-			picker.TryAdd(path);
+			TryAdd(path);
 
 	auto delBros = [&srcs](cmstring& mine)
 	{
 		string base;
 		int nDeleted = 0;
 		cmstring* pMySuf=nullptr;
-		for(const auto& suf: compSuffixesAndEmpty)
+		for(const auto& suf: sfxXzBz2GzLzmaNone)
 		{
 			if(endsWith(mine, suf))
 			{
@@ -177,7 +167,7 @@ void pkgmirror::Action()
 				break;
 			}
 		}
-		for(const auto& suf : compSuffixesAndEmpty)
+		for(const auto& suf : sfxXzBz2GzLzmaNone)
 		{
 			if(&suf == pMySuf)
 				continue;
@@ -199,7 +189,7 @@ void pkgmirror::Action()
 	// now there may still be something like Sources and Sources.bz2 if they
 	// were added by Release file scan. Choose the preferred one simply by extension.
 	restart_clean2: // start over if the set changed while having a hot iterator
-	for (const auto& s: compSuffixesAndEmptyByRatio)
+	for (const auto& s: sfxXzBz2GzLzma)
 		for (const auto& src : srcs)
 			if (endsWith(src, s)&& delBros(src)) // this is the one
 				goto restart_clean2;
@@ -237,7 +227,8 @@ void pkgmirror::Action()
 #endif
 			off_t needBefore=(m_totalSize-m_totalHave);
 
-			ParseAndProcessMetaFile(*this, src, GuessMetaTypeFromURL(src));
+			ParseAndProcessMetaFile([this](const tRemoteFileInfo &e) {
+				HandlePkgEntry(e); }, src, GuessMetaTypeFromURL(src));
 
 			SendFmt << src << ": "
 					<< offttosH((m_totalSize-m_totalHave)-needBefore)
@@ -267,7 +258,8 @@ void pkgmirror::Action()
 			if(CheckStopSignal())
 				return;
 			ConfigDelta(src);
-			ParseAndProcessMetaFile(*this, src, GuessMetaTypeFromURL(src));
+			ParseAndProcessMetaFile([this](const tRemoteFileInfo &e) {
+				HandlePkgEntry(e); }, src, GuessMetaTypeFromURL(src));
 		}
 	}
 }
