@@ -46,14 +46,10 @@ inline bool IsIndexDiff(const string & sPath)
 }
 */
 
-bool pkgimport::ProcessRegular(cmstring &sPath, const struct stat &stinfo)
+bool pkgimport::ProcessRegular(const mstring &sPath, const struct stat &stinfo)
 {
+	if(CheckStopSignal()) return false;
 
-	{
-		lockguard g(&abortMx);
-		if(bSigTaskAbort)
-			return false;
-	}
 	if(endsWithSzAr(sPath, ".head"))
 		return true;
 
@@ -179,9 +175,7 @@ void pkgimport::Action()
 	m_sSrcPath=CACHE_BASE+"_import";
 	
 	SendFmt << "Importing from " << m_sSrcPath << " directory.<br>Scanning local files...<br>";
-	
-	SetCommonUserFlags(m_parms.cmd);
-	m_bErrAbort=false; // does not f...ing matter, do what we can
+
 	m_bByPath=true; // should act on all locations
 
 	_LoadKeyCache();
@@ -191,13 +185,9 @@ void pkgimport::Action()
 				<<" from the fingerprint cache<br>\n");
 	
 	m_bLookForIFiles=true;
-	DirectoryWalk(acfg::cachedir, this, true);
 
-	{
-		lockguard g(&abortMx);
-		if(bSigTaskAbort)
-			return;
-	}
+	BuildCacheFileList();
+	if(CheckStopSignal()) return;
 	
 	if(m_metaFilesRel.empty())
 	{
@@ -207,12 +197,7 @@ void pkgimport::Action()
 
 
 	UpdateVolatileFiles();
-
-	{
-		lockguard g(&abortMx);
-		if(bSigTaskAbort)
-			return;
-	}
+	if(CheckStopSignal()) return;
 	
 	if(m_bErrAbort && m_nErrorCount>0)
 	{
@@ -223,12 +208,7 @@ void pkgimport::Action()
 	m_bLookForIFiles=false;
 	DBGQLOG("building contents map for " << m_sSrcPath);
 	DirectoryWalk(m_sSrcPath, this, true);
-
-	{
-		lockguard g(&abortMx);
-		if(bSigTaskAbort)
-			return;
-	}
+	if(CheckStopSignal()) return;
 	
 	if(m_importMap.empty())
 	{
@@ -236,13 +216,10 @@ void pkgimport::Action()
 		return;
 	}
 	
-	ProcessSeenMetaFiles(*this);
+	ProcessSeenIndexFiles([this](const tRemoteFileInfo &e) {
+		HandlePkgEntry(e); });
 
-	{
-		lockguard g(&abortMx);
-		if(bSigTaskAbort)
-			return;
-	}
+	if(CheckStopSignal()) return;
 
 	ofstream fList;
 	fList.open(SCACHEFILE.c_str(), ios::out | ios::trunc);
