@@ -257,7 +257,7 @@ void tcpconnect::Disconnect()
 
 	termsocket_quick(m_conFd);
 }
-lockable spareConPoolMx;
+acmutex spareConPoolMx;
 multimap<tuple<string,string SSL_OPT_ARG(bool) >,
 		std::pair<tDlStreamHandle, time_t> > spareConPool;
 
@@ -383,7 +383,7 @@ void dl_con_factory::RecycleIdleConnection(tDlStreamHandle & handle)
 		// a DOS?
 		if (spareConPool.size() < 50)
 		{
-			EMPLACE_PAIR(spareConPool, make_tuple(host, handle->GetPort()
+			EMPLACE_PAIR_COMPAT(spareConPool, make_tuple(host, handle->GetPort()
 					SSL_OPT_ARG(handle->m_bio) ), make_pair(handle, now));
 #ifndef MINIBUILD
 			g_victor.ScheduleFor(now + TIME_SOCKET_EXPIRE_CLOSE, cleaner::TYPE_EXCONNS);
@@ -627,7 +627,7 @@ bool tcpconnect::StartTunnel(const tHttpUrl& realTarget, mstring& sError,
 			}
 
 			header h;
-			auto n = h.LoadFromBuf(fmt.rptr(), fmt.size());
+			auto n = h.Load(fmt.rptr(), fmt.size());
 			if(!n)
 				continue;
 
